=== modified file 'client/drizzledump.cc'
--- client/drizzledump.cc	2009-03-24 04:39:25 +0000
+++ client/drizzledump.cc	2009-03-25 08:02:36 +0000
@@ -61,7 +61,7 @@
 
 /* Size of buffer for dump's select query */
 #define QUERY_LENGTH 1536
-#define DRIZZLE_MAX_LINE_LENGTH 8192
+#define DRIZZLE_MAX_LINE_LENGTH 1024*1024L-1025
 
 /* ignore table flags */
 #define IGNORE_NONE 0x00 /* no ignore */
@@ -845,10 +845,18 @@
 /*
 ** DB_error -- prints DRIZZLE error message and exits the program.
 */
-static void DB_error(drizzle_con_st *con, const char *when)
+static void DB_error(drizzle_result_st *res, drizzle_return_t ret,
+                     const char *when)
 {
+  if (ret == DRIZZLE_RETURN_ERROR_CODE)
+  {
+    maybe_die(EX_DRIZZLEERR, _("Got error: %s %s"),
+              drizzle_result_error_code(res), when);
+    drizzle_result_free(res);
+  }
+  else
+    maybe_die(EX_DRIZZLEERR, _("Got error: %s %s"), ret, when);
 
-  maybe_die(EX_DRIZZLEERR, _("Got error: %s %s"), drizzle_con_error(con), when);
   return;
 }
 
@@ -935,18 +943,40 @@
 
 static int drizzleclient_query_with_error_report(drizzle_con_st *con,
                                                  drizzle_result_st *result,
-                                                 const char *query)
+                                                 const char *query, bool quick)
 {
   drizzle_return_t ret;
 
   if (drizzle_query_str(con, result, query, &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK ||
-      drizzle_result_buffer(result) != DRIZZLE_RETURN_OK)
-  {
+      ret != DRIZZLE_RETURN_OK)
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      maybe_die(EX_DRIZZLEERR, _("Couldn't execute '%s': %s (%d)"),
+                query, drizzle_result_error(result),
+                drizzle_result_error_code(result));
+      drizzle_result_free(result);
+    }
+    else
+    {
+      maybe_die(EX_DRIZZLEERR, _("Couldn't execute '%s': %s (%d)"),
+                query, drizzle_con_error(con), ret);
+    }
+    return 1;
+  }
+
+  if (quick)
+    ret= drizzle_column_buffer(result);
+  else
+    ret= drizzle_result_buffer(result);
+  if (ret != DRIZZLE_RETURN_OK)
+  {
+    drizzle_result_free(result);
     maybe_die(EX_DRIZZLEERR, _("Couldn't execute '%s': %s (%d)"),
-            query, drizzle_con_error(con), ret);
+              query, drizzle_con_error(con), ret);
     return 1;
   }
+
   return 0;
 }
 
@@ -1004,14 +1034,17 @@
 
 static int connect_to_db(char *host, char *user,char *passwd)
 {
+  drizzle_return_t ret;
+
   verbose_msg(_("-- Connecting to %s...\n"), host ? host : "localhost");
   drizzle_create(&drizzle);
   drizzle_con_create(&drizzle, &dcon);
   drizzle_con_set_tcp(&dcon, host, opt_drizzle_port);
   drizzle_con_set_auth(&dcon, user, passwd);
-  if (drizzle_con_connect(&dcon) != DRIZZLE_RETURN_OK)
+  ret= drizzle_con_connect(&dcon);
+  if (ret != DRIZZLE_RETURN_OK)
   {
-    DB_error(&dcon, "when trying to connect");
+    DB_error(NULL, ret, "when trying to connect");
     return(1);
   }
 
@@ -1415,13 +1448,16 @@
 
       snprintf(buff, sizeof(buff), "show create table %s", result_table);
 
-      if (drizzleclient_query_with_error_report(&dcon, &result, buff))
+      if (drizzleclient_query_with_error_report(&dcon, &result, buff, false))
         return false;
 
       if (path)
       {
         if (!(sql_file= open_sql_file_for_table(table)))
+        {
+          drizzle_result_free(&result);
           return false;
+        }
 
         write_header(sql_file, db);
       }
@@ -1449,9 +1485,11 @@
       check_io(sql_file);
       drizzle_result_free(&result);
     }
+
     snprintf(query_buff, sizeof(query_buff), "show fields from %s",
              result_table);
-    if (drizzleclient_query_with_error_report(&dcon, &result, query_buff))
+
+    if (drizzleclient_query_with_error_report(&dcon, &result, query_buff, false))
     {
       if (path)
         fclose(sql_file);
@@ -1497,7 +1535,7 @@
         insert_pat.append(quote_name(row[SHOW_FIELDNAME], name_buff, 0));
       }
     }
-    *num_fields= drizzle_result_column_count(&result);
+    *num_fields= drizzle_result_row_count(&result);
     drizzle_result_free(&result);
   }
   else
@@ -1507,7 +1545,7 @@
 
     snprintf(query_buff, sizeof(query_buff), "show fields from %s",
              result_table);
-    if (drizzleclient_query_with_error_report(&dcon, &result, query_buff))
+    if (drizzleclient_query_with_error_report(&dcon, &result, query_buff, false))
       return false;
 
     /* Make an sql-file, if path was given iow. option -T was given */
@@ -1600,22 +1638,17 @@
     }
     *num_fields= drizzle_result_row_count(&result);
     drizzle_result_free(&result);
+
     if (!opt_no_create_info)
     {
       /* Make an sql-file, if path was given iow. option -T was given */
       char buff[20+FN_REFLEN];
       uint32_t keynr,primary_key;
       snprintf(buff, sizeof(buff), "show keys from %s", result_table);
-      if (drizzleclient_query_with_error_report(dcon, &result, buff))
+      if (drizzleclient_query_with_error_report(&dcon, &result, buff, false))
       {
-        if (drizzleclient_errno(drizzle) == ER_WRONG_OBJECT)
-        {
-          /* it is VIEW */
-          fputs("\t\t<options Comment=\"view\" />\n", sql_file);
-          goto continue_xml;
-        }
-        fprintf(stderr, _("%s: Can't get keys for table %s (%s)\n"),
-                my_progname, result_table, drizzleclient_error(drizzle));
+        fprintf(stderr, _("%s: Can't get keys for table %s\n"),
+                my_progname, result_table);
         if (path)
           fclose(sql_file);
         return false;
@@ -1624,7 +1657,7 @@
       /* Find first which key is primary key */
       keynr=0;
       primary_key=INT_MAX;
-      while ((row= drizzleclient_fetch_row(result)))
+      while ((row= drizzle_row_next(&result)))
       {
         if (atoi(row[3]) == 1)
         {
@@ -1640,13 +1673,13 @@
           }
         }
       }
-      drizzleclient_data_seek(result,0);
+      drizzle_row_seek(&result,0);
       keynr=0;
-      while ((row= drizzleclient_fetch_row(result)))
+      while ((row= drizzle_row_next(&result)))
       {
         if (opt_xml)
         {
-          print_xml_row(sql_file, "key", result, &row);
+          print_xml_row(sql_file, "key", &result, &row);
           continue;
         }
 
@@ -1670,7 +1703,7 @@
           fprintf(sql_file, " (%s)",row[7]);      /* Sub key */
         check_io(sql_file);
       }
-      drizzleclient_free_result(result);
+      drizzle_result_free(&result);
       if (!opt_xml)
       {
         if (keynr)
@@ -1681,44 +1714,38 @@
       /* Get DRIZZLE specific create options */
       if (create_options)
       {
-        char show_name_buff[NAME_LEN*2+2+24];
+        char show_name_buff[DRIZZLE_MAX_COLUMN_NAME_SIZE*2+2+24];
 
         /* Check memory for quote_for_like() */
         snprintf(buff, sizeof(buff), "show table status like %s",
                  quote_for_like(table, show_name_buff));
 
-        if (drizzleclient_query_with_error_report(dcon, &result, buff))
+        if (!drizzleclient_query_with_error_report(&dcon, &result, buff, false))
         {
-          if (drizzleclient_errno(drizzle) != ER_PARSE_ERROR)
-          {                                     /* If old DRIZZLE version */
-            verbose_msg(_("-- Warning: Couldn't get status information for " \
-                        "table %s (%s)\n"), result_table,drizzleclient_error(drizzle));
+          if (!(row= drizzle_row_next(&result)))
+          {
+            fprintf(stderr,
+                    _("Error: Couldn't read status information for table %s\n"),
+                    result_table);
           }
-        }
-        else if (!(row= drizzleclient_fetch_row(result)))
-        {
-          fprintf(stderr,
-                  _("Error: Couldn't read status information for table %s (%s)\n"),
-                  result_table,drizzleclient_error(drizzle));
-        }
-        else
-        {
-          if (opt_xml)
-            print_xml_row(sql_file, "options", result, &row);
           else
           {
-            fputs("/*!",sql_file);
-            print_value(sql_file,result,row,"engine=","Engine",0);
-            print_value(sql_file,result,row,"","Create_options",0);
-            print_value(sql_file,result,row,"comment=","Comment",1);
+            if (opt_xml)
+              print_xml_row(sql_file, "options", &result, &row);
+            else
+            {
+              fputs("/*!",sql_file);
+              print_value(sql_file,&result,row,"engine=","Engine",0);
+              print_value(sql_file,&result,row,"","Create_options",0);
+              print_value(sql_file,&result,row,"comment=","Comment",1);
 
-            fputs(" */",sql_file);
-            check_io(sql_file);
+              fputs(" */",sql_file);
+              check_io(sql_file);
+            }
           }
+          drizzle_result_free(&result);
         }
-        drizzleclient_free_result(result);              /* Is always safe to free */
       }
-continue_xml:
       if (!opt_xml)
         fputs(";\n", sql_file);
       else
@@ -1822,16 +1849,17 @@
 static void dump_table(char *table, char *db)
 {
   char ignore_flag;
-  char buf[200], table_buff[NAME_LEN+3];
+  char table_buff[DRIZZLE_MAX_TABLE_SIZE+3];
   string query_string;
-  char table_type[NAME_LEN];
-  char *result_table, table_buff2[NAME_LEN*2+3], *opt_quoted_table;
+  char table_type[DRIZZLE_MAX_TABLE_SIZE];
+  char *result_table, table_buff2[DRIZZLE_MAX_TABLE_SIZE*2+3], *opt_quoted_table;
   int error= 0;
   uint32_t rownr, row_break, total_length, init_length;
   uint64_t num_fields= 0;
-  drizzle_result_st     *res;
-  DRIZZLE_FIELD   *field;
-  drizzle_row_t     row;
+  drizzle_return_t ret;
+  drizzle_result_st result;
+  drizzle_column_st *column;
+  drizzle_row_t row;
 
 
   /*
@@ -1923,11 +1951,15 @@
       query_string.append( order_by);
     }
 
-    if (drizzleclient_real_query(drizzle, query_string.c_str(), query_string.length()))
+    if (drizzle_query(&dcon, &result, query_string.c_str(),
+                      query_string.length(), &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
     {
-      DB_error(drizzle, _("when executing 'SELECT INTO OUTFILE'"));
+      DB_error(&result, ret, _("when executing 'SELECT INTO OUTFILE'"));
+
       return;
     }
+    drizzle_result_free(&result);
   }
   else
   {
@@ -1968,28 +2000,19 @@
       fputs("\n", md_result_file);
       check_io(md_result_file);
     }
-    if (drizzleclient_query_with_error_report(dcon, &result,
-                                              query_string.c_str()))
-    {
-      DB_error(drizzle, _("when retrieving data from server"));
-      goto err;
-    }
-    if (quick)
-      res=drizzleclient_use_result(drizzle);
-    else
-      res=drizzleclient_store_result(drizzle);
-    if (!res)
-    {
-      DB_error(drizzle, _("when retrieving data from server"));
+    if (drizzleclient_query_with_error_report(&dcon, &result,
+                                              query_string.c_str(), quick))
+    {
       goto err;
     }
 
     verbose_msg(_("-- Retrieving rows...\n"));
-    if (drizzleclient_num_fields(res) != num_fields)
+    if (drizzle_result_column_count(&result) != num_fields)
     {
       fprintf(stderr,_("%s: Error in field count for table: %s !  Aborting.\n"),
               my_progname, result_table);
       error= EX_CONSCHECK;
+      drizzle_result_free(&result);
       goto err;
     }
 
@@ -2019,10 +2042,36 @@
       check_io(md_result_file);
     }
 
-    while ((row= drizzleclient_fetch_row(res)))
+    row= NULL;
+
+    while (1)
     {
       uint32_t i;
-      uint32_t *lengths= drizzleclient_fetch_lengths(res);
+      size_t *lengths;
+
+      if (quick)
+      {
+        if (row)
+          drizzle_row_free(&result, row);
+
+        row= drizzle_row_buffer(&result, &ret);
+        if (ret != DRIZZLE_RETURN_OK)
+        {
+          fprintf(stderr,
+                _("%s: Error reading rows for table: %s (%d:%s) ! Aborting.\n"),
+                  my_progname, result_table, ret, drizzle_con_error(&dcon));
+          drizzle_result_free(&result);
+          goto err;
+        }
+      }
+      else
+        row= drizzle_row_next(&result);
+
+      if (row == NULL)
+        break;
+
+      lengths= drizzle_row_field_sizes(&result);
+
       rownr++;
       if ((rownr % show_progress_size) == 0)
       {
@@ -2033,7 +2082,7 @@
         fputs(insert_pat.c_str(),md_result_file);
         check_io(md_result_file);
       }
-      drizzleclient_field_seek(res,0);
+      drizzle_column_seek(&result,0);
 
       if (opt_xml)
       {
@@ -2041,12 +2090,12 @@
         check_io(md_result_file);
       }
 
-      for (i= 0; i < drizzleclient_num_fields(res); i++)
+      for (i= 0; i < drizzle_result_column_count(&result); i++)
       {
         int is_blob;
         uint32_t length= lengths[i];
 
-        if (!(field= drizzleclient_fetch_field(res)))
+        if (!(column= drizzle_column_next(&result)))
           die(EX_CONSCHECK,
                       _("Not enough fields from table %s! Aborting.\n"),
                       result_table);
@@ -2056,9 +2105,9 @@
            we have not a BLOB but a TEXT column.
            we'll dump in hex only BLOB columns.
         */
-        is_blob= (opt_hex_blob && field->charsetnr == 63 &&
-                  (field->type == DRIZZLE_TYPE_VARCHAR ||
-                   field->type == DRIZZLE_TYPE_BLOB)) ? 1 : 0;
+        is_blob= (opt_hex_blob && drizzle_column_charset(column) == 63 &&
+                  (drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_VARCHAR ||
+                   drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_BLOB)) ? 1 : 0;
         if (extended_insert && !opt_xml)
         {
           if (i == 0)
@@ -2073,7 +2122,7 @@
           {
             if (length)
             {
-              if (!(field->type & NUM_FLAG))
+              if (!(drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_NUM))
               {
                 /*
                   "length * 2 + 2" is OK for both HEX and non-HEX modes:
@@ -2088,14 +2137,13 @@
                 if (opt_hex_blob && is_blob)
                 {
                   extended_row.append("0x");
-                  drizzleclient_drizzleclient_octet2hex(tmp_str, row[i], length);
+                  drizzle_hex_string(tmp_str, row[i], length);
                   extended_row.append(tmp_str);
                 }
                 else
                 {
                   extended_row.append("'");
-                  drizzleclient_escape_string(tmp_str,
-                                        row[i],length);
+                  drizzle_escape_string(tmp_str, row[i],length);
                   extended_row.append(tmp_str);
                   extended_row.append("'");
                 }
@@ -2129,7 +2177,7 @@
           }
           if (row[i])
           {
-            if (!(field->type & NUM_FLAG))
+            if (!(drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_NUM))
             {
               if (opt_xml)
               {
@@ -2137,13 +2185,13 @@
                 {
                   /* Define xsi:type="xs:hexBinary" for hex encoded data */
                   print_xml_tag(md_result_file, "\t\t", "", "field", "name=",
-                                field->name, "xsi:type=", "xs:hexBinary", NULL);
+                                drizzle_column_name(column), "xsi:type=", "xs:hexBinary", NULL);
                   print_blob_as_hex(md_result_file, row[i], length);
                 }
                 else
                 {
                   print_xml_tag(md_result_file, "\t\t", "", "field", "name=",
-                                field->name, NULL);
+                                drizzle_column_name(column), NULL);
                   print_quoted_xml(md_result_file, row[i], length);
                 }
                 fputs("</field>\n", md_result_file);
@@ -2163,7 +2211,7 @@
               if (opt_xml)
               {
                 print_xml_tag(md_result_file, "\t\t", "", "field", "name=",
-                        field->name, NULL);
+                        drizzle_column_name(column), NULL);
                 fputs(!my_isalpha(charset_info, *ptr) ? ptr: "NULL",
                       md_result_file);
                 fputs("</field>\n", md_result_file);
@@ -2182,7 +2230,7 @@
               fputs("NULL", md_result_file);
             else
               print_xml_null_tag(md_result_file, "\t\t", "field name=",
-                                 field->name, "\n");
+                                 drizzle_column_name(column), "\n");
           }
           check_io(md_result_file);
         }
@@ -2231,19 +2279,6 @@
       fputs(";\n", md_result_file);             /* If not empty table */
     fflush(md_result_file);
     check_io(md_result_file);
-    if (drizzleclient_errno(drizzle))
-    {
-      snprintf(buf, sizeof(buf),
-               _("%s: Error %d: %s when dumping table %s at row: %d\n"),
-               my_progname,
-               drizzleclient_errno(drizzle),
-               drizzleclient_error(drizzle),
-               result_table,
-               rownr);
-      fputs(buf,stderr);
-      error= EX_CONSCHECK;
-      goto err;
-    }
 
     /* Moved enable keys to before unlock per bug 15977 */
     if (opt_disable_keys)
@@ -2262,7 +2297,7 @@
       fprintf(md_result_file, "commit;\n");
       check_io(md_result_file);
     }
-    drizzleclient_free_result(res);
+    drizzle_result_free(&result);
   }
   return;
 
@@ -2274,41 +2309,45 @@
 
 static char *getTableName(int reset)
 {
-  static drizzle_result_st *res= NULL;
-  drizzle_row_t    row;
+  static drizzle_result_st result;
+  static bool have_result= false;
+  drizzle_row_t row;
 
-  if (!res)
+  if (!have_result)
   {
-    if (!(res= drizzleclient_list_tables(drizzle,NULL)))
-      return(NULL);
+    if (drizzleclient_query_with_error_report(&dcon, &result, "SHOW TABLES", false))
+      return NULL;
+    have_result= true;
   }
-  if ((row= drizzleclient_fetch_row(res)))
-    return((char*) row[0]);
+
+  if ((row= drizzle_row_next(&result)))
+    return row[0];
 
   if (reset)
-    drizzleclient_data_seek(res,0);      /* We want to read again */
+    drizzle_row_seek(&result, 0);
   else
   {
-    drizzleclient_free_result(res);
-    res= NULL;
+    drizzle_result_free(&result);
+    have_result= false;
   }
-  return(NULL);
+  return NULL;
 } /* getTableName */
 
 
 static int dump_all_databases()
 {
   drizzle_row_t row;
-  drizzle_result_st *tableres;
+  drizzle_result_st tableres;
   int result=0;
 
-  if (drizzleclient_query_with_error_report(dcon, &tableres, "SHOW DATABASES"))
+  if (drizzleclient_query_with_error_report(&dcon, &tableres, "SHOW DATABASES", false))
     return 1;
-  while ((row= drizzleclient_fetch_row(tableres)))
+  while ((row= drizzle_row_next(&tableres)))
   {
     if (dump_all_tables_in_db(row[0]))
       result=1;
   }
+  drizzle_result_free(&tableres);
   return result;
 }
 /* dump_all_databases */
@@ -2343,20 +2382,23 @@
 
 int init_dumping_tables(char *qdatabase)
 {
-
-
   if (!opt_create_db)
   {
     char qbuf[256];
     drizzle_row_t row;
-    drizzle_result_st *dbinfo;
+    drizzle_result_st result;
+    drizzle_return_t ret;
 
     snprintf(qbuf, sizeof(qbuf),
              "SHOW CREATE DATABASE IF NOT EXISTS %s",
              qdatabase);
 
-    if (drizzleclient_query(drizzle, qbuf) || !(dbinfo = drizzleclient_store_result(drizzle)))
+    if (drizzle_query_str(&dcon, &result, qbuf, &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
     {
+      if (ret == DRIZZLE_RETURN_ERROR_CODE)
+        drizzle_result_free(&result);
+
       /* Old server version, dump generic CREATE DATABASE */
       if (opt_drop_database)
         fprintf(md_result_file,
@@ -2368,16 +2410,19 @@
     }
     else
     {
-      if (opt_drop_database)
-        fprintf(md_result_file,
-                "\nDROP DATABASE IF EXISTS %s;\n",
-                qdatabase);
-      row = drizzleclient_fetch_row(dbinfo);
-      if (row[1])
+      if (drizzle_result_buffer(&result) == DRIZZLE_RETURN_OK)
       {
-        fprintf(md_result_file,"\n%s;\n",row[1]);
+        if (opt_drop_database)
+          fprintf(md_result_file,
+                  "\nDROP DATABASE IF EXISTS %s;\n",
+                  qdatabase);
+        row = drizzle_row_next(&result);
+        if (row != NULL && row[1])
+        {
+          fprintf(md_result_file,"\n%s;\n",row[1]);
+        }
       }
-      drizzleclient_free_result(dbinfo);
+      drizzle_result_free(&result);
     }
   }
   return(0);
@@ -2386,15 +2431,20 @@
 
 static int init_dumping(char *database, int init_func(char*))
 {
-  if (drizzleclient_get_server_version(drizzle) >= 50003 &&
-      !my_strcasecmp(&my_charset_utf8_general_ci, database, "information_schema"))
+  drizzle_result_st result;
+  drizzle_return_t ret;
+
+  if (!my_strcasecmp(&my_charset_utf8_general_ci, database, "information_schema"))
     return 1;
 
-  if (drizzleclient_select_db(drizzle, database))
+  if (drizzle_select_db(&dcon, &result, database, &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
   {
-    DB_error(drizzle, _("when selecting the database"));
+    DB_error(&result, ret, _("when executing 'SELECT INTO OUTFILE'"));
     return 1;                   /* If --force */
   }
+  drizzle_result_free(&result);
+
   if (!path && !opt_xml)
   {
     if (opt_databases || opt_alldbs)
@@ -2402,7 +2452,7 @@
       /*
         length of table name * 2 (if name contains quotes), 2 quotes and 0
       */
-      char quoted_database_buf[NAME_LEN*2+3];
+      char quoted_database_buf[DRIZZLE_MAX_DB_SIZE*2+3];
       char *qdatabase= quote_name(database,quoted_database_buf,opt_quoted);
       if (opt_comments)
       {
@@ -2435,9 +2485,11 @@
 {
   char *table;
   uint32_t numrows;
-  char table_buff[NAME_LEN*2+3];
-  char hash_key[2*NAME_LEN+2];  /* "db.tablename" */
+  char table_buff[DRIZZLE_MAX_TABLE_SIZE*2+3];
+  char hash_key[DRIZZLE_MAX_DB_SIZE+DRIZZLE_MAX_TABLE_SIZE+2];  /* "db.tablename" */
   char *afterdot;
+  drizzle_result_st result;
+  drizzle_return_t ret;
 
   afterdot= strcpy(hash_key, database) + strlen(database);
   *afterdot++= '.';
@@ -2459,16 +2511,30 @@
         query.append( " READ LOCAL,");
       }
     }
-    if (numrows && drizzleclient_real_query(drizzle, query.c_str(), query.length()-1))
-      DB_error(drizzle, _("when using LOCK TABLES"));
-            /* We shall continue here, if --force was given */
+    if (numrows)
+    {
+      if (drizzle_query(&dcon, &result, query.c_str(),
+                        query.length()-1, &ret) == NULL ||
+          ret != DRIZZLE_RETURN_OK)
+      {
+        DB_error(&result, ret, _("when using LOCK TABLES"));
+        /* We shall continue here, if --force was given */
+      }
+      else
+        drizzle_result_free(&result);
+    }
     query.clear();
   }
   if (flush_logs)
   {
-    if (drizzleclient_real_query(drizzle, "FLUSH LOGS", strlen("FLUSH LOGS")))
-      DB_error(drizzle, _("when doing refresh"));
-           /* We shall continue here, if --force was given */
+    if (drizzle_query_str(&dcon, &result, "FLUSH LOGS", &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
+    {
+      DB_error(&result, ret, _("when doing refresh"));
+      /* We shall continue here, if --force was given */
+    }
+    else
+      drizzle_result_free(&result);
   }
   while ((table= getTableName(0)))
   {
@@ -2486,7 +2552,10 @@
     check_io(md_result_file);
   }
   if (lock_tables)
-    drizzleclient_query_with_error_report(dcon, &result, "UNLOCK TABLES");
+  {
+    if (!drizzleclient_query_with_error_report(&dcon, &result, "UNLOCK TABLES", false))
+      drizzle_result_free(&result);
+  }
 
   return(0);
 } /* dump_all_tables_in_db */
@@ -2506,10 +2575,11 @@
 static char *get_actual_table_name(const char *old_table_name, MEM_ROOT *root)
 {
   char *name= 0;
-  drizzle_result_st  *table_res;
+  drizzle_result_st result;
   drizzle_row_t  row;
-  char query[50 + 2*NAME_LEN];
+  char query[50 + 2*DRIZZLE_MAX_TABLE_SIZE];
   char show_name_buff[FN_REFLEN];
+  uint64_t num_rows;
 
 
   /* Check memory for quote_for_like() */
@@ -2517,35 +2587,35 @@
   snprintf(query, sizeof(query), "SHOW TABLES LIKE %s",
            quote_for_like(old_table_name, show_name_buff));
 
-  if (drizzleclient_query_with_error_report(dcon, &result, query))
+  if (drizzleclient_query_with_error_report(&dcon, &result, query, false))
     return NULL;
 
-  if ((table_res= drizzleclient_store_result(drizzle)))
+  num_rows= drizzle_result_row_count(&result);
+  if (num_rows > 0)
   {
-    uint64_t num_rows= drizzleclient_num_rows(table_res);
-    if (num_rows > 0)
-    {
-      uint32_t *lengths;
-      /*
-        Return first row
-        TODO: Return all matching rows
-      */
-      row= drizzleclient_fetch_row(table_res);
-      lengths= drizzleclient_fetch_lengths(table_res);
-      name= strmake_root(root, row[0], lengths[0]);
-    }
-    drizzleclient_free_result(table_res);
+    size_t *lengths;
+    /*
+      Return first row
+      TODO: Return all matching rows
+    */
+    row= drizzle_row_next(&result);
+    lengths= drizzle_row_field_sizes(&result);
+    name= strmake_root(root, row[0], lengths[0]);
   }
+  drizzle_result_free(&result);
+
   return(name);
 }
 
 
 static int dump_selected_tables(char *db, char **table_names, int tables)
 {
-  char table_buff[NAME_LEN*2+3];
+  char table_buff[DRIZZLE_MAX_TABLE_SIZE*2+3];
   string lock_tables_query("LOCK TABLES ");
   MEM_ROOT root;
   char **dump_tables, **pos, **end;
+  drizzle_result_st result;
+  drizzle_return_t ret;
 
 
   if (init_dumping(db, init_dumping_tables))
@@ -2582,26 +2652,32 @@
 
   if (lock_tables)
   {
-    if (drizzleclient_real_query(drizzle, lock_tables_query.c_str(),
-                         lock_tables_query.length()-1))
+    if (drizzle_query(&dcon, &result, lock_tables_query.c_str(),
+                      lock_tables_query.length()-1, &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
     {
       if (!ignore_errors)
       {
         free_root(&root, MYF(0));
       }
-      DB_error(drizzle, _("when doing LOCK TABLES"));
-       /* We shall countinue here, if --force was given */
+      DB_error(&result, ret, _("when doing LOCK TABLES"));
+      /* We shall countinue here, if --force was given */
     }
+    else
+      drizzle_result_free(&result);
   }
   if (flush_logs)
   {
-    if (drizzleclient_real_query(drizzle, "FLUSH LOGS", strlen("FLUSH LOGS")))
+    if (drizzle_query_str(&dcon, &result, "FLUSH LOGS", &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
     {
       if (!ignore_errors)
         free_root(&root, MYF(0));
-      DB_error(drizzle, _("when doing refresh"));
+      DB_error(&result, ret, _("when doing refresh"));
+      /* We shall countinue here, if --force was given */
     }
-     /* We shall countinue here, if --force was given */
+    else
+      drizzle_result_free(&result);
   }
   if (opt_xml)
     print_xml_tag(md_result_file, "", "\n", "database", "name=", db, NULL);
@@ -2619,7 +2695,10 @@
     check_io(md_result_file);
   }
   if (lock_tables)
-    drizzleclient_query_with_error_report(dcon, &result, "UNLOCK TABLES");
+  {
+    if (!(drizzleclient_query_with_error_report(&dcon, &result, "UNLOCK TABLES", false)))
+      drizzle_result_free(&result);
+  }
   return(0);
 } /* dump_selected_tables */
 
@@ -2630,13 +2709,13 @@
   drizzle_result_st master;
   const char *comment_prefix=
     (opt_master_data == DRIZZLE_OPT_MASTER_DATA_COMMENTED_SQL) ? "-- " : "";
-  if (drizzleclient_query_with_error_report(drizzle_con, &master, "SHOW MASTER STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &master, "SHOW MASTER STATUS", false))
   {
     return 1;
   }
   else
   {
-    row= drizzleclient_fetch_row(master);
+    row= drizzle_row_next(&master);
     if (row && row[0] && row[1])
     {
       /* SHOW MASTER STATUS reports file and position */
@@ -2654,40 +2733,41 @@
       /* SHOW MASTER STATUS reports nothing and --force is not enabled */
       my_printf_error(0, _("Error: Binlogging on server not active"),
                       MYF(0));
-      drizzleclient_free_result(master);
+      drizzle_result_free(&master);
       maybe_exit(EX_DRIZZLEERR);
       return 1;
     }
-    drizzleclient_free_result(master);
+    drizzle_result_free(&master);
   }
   return 0;
 }
 
-static int do_stop_slave_sql(DRIZZLE *drizzle_con)
+static int do_stop_slave_sql(drizzle_con_st *drizzle_con)
 {
-  drizzle_result_st *slave;
+  drizzle_result_st slave;
   /* We need to check if the slave sql is running in the first place */
-  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS", false))
     return(1);
   else
   {
-    drizzle_row_t row= drizzleclient_fetch_row(slave);
+    drizzle_row_t row= drizzle_row_next(&slave);
     if (row && row[11])
     {
       /* if SLAVE SQL is not running, we don't stop it */
       if (!strcmp(row[11],"No"))
       {
-        drizzleclient_free_result(slave);
+        drizzle_result_free(&slave);
         /* Silently assume that they don't have the slave running */
         return(0);
       }
     }
   }
-  drizzleclient_free_result(slave);
+  drizzle_result_free(&slave);
 
   /* now, stop slave if running */
-  if (drizzleclient_query_with_error_report(drizzle_con, 0, "STOP SLAVE SQL_THREAD"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "STOP SLAVE SQL_THREAD", false))
     return(1);
+  drizzle_result_free(&slave);
 
   return(0);
 }
@@ -2710,12 +2790,12 @@
   return(0);
 }
 
-static int do_show_slave_status(DRIZZLE *drizzle_con)
+static int do_show_slave_status(drizzle_con_st *drizzle_con)
 {
-  drizzle_result_st *slave;
+  drizzle_result_st slave;
   const char *comment_prefix=
     (opt_slave_data == DRIZZLE_OPT_SLAVE_DATA_COMMENTED_SQL) ? "-- " : "";
-  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS", false))
   {
     if (!ignore_errors)
     {
@@ -2726,7 +2806,7 @@
   }
   else
   {
-    drizzle_row_t row= drizzleclient_fetch_row(slave);
+    drizzle_row_t row= drizzle_row_next(&slave);
     if (row && row[9] && row[21])
     {
       /* SHOW MASTER STATUS reports file and position */
@@ -2749,45 +2829,46 @@
 
       check_io(md_result_file);
     }
-    drizzleclient_free_result(slave);
+    drizzle_result_free(&slave);
   }
   return 0;
 }
 
-static int do_start_slave_sql(DRIZZLE *drizzle_con)
+static int do_start_slave_sql(drizzle_con_st *drizzle_con)
 {
-  drizzle_result_st *slave;
+  drizzle_result_st slave;
   /* We need to check if the slave sql is stopped in the first place */
-  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "SHOW SLAVE STATUS", false))
     return(1);
   else
   {
-    drizzle_row_t row= drizzleclient_fetch_row(slave);
+    drizzle_row_t row= drizzle_row_next(&slave);
     if (row && row[11])
     {
       /* if SLAVE SQL is not running, we don't start it */
       if (!strcmp(row[11],"Yes"))
       {
-        drizzleclient_free_result(slave);
+        drizzle_result_free(&slave);
         /* Silently assume that they don't have the slave running */
         return(0);
       }
     }
+    drizzle_result_free(&slave);
   }
-  drizzleclient_free_result(slave);
 
   /* now, start slave if stopped */
-  if (drizzleclient_query_with_error_report(drizzle_con, 0, "START SLAVE"))
+  if (drizzleclient_query_with_error_report(drizzle_con, &slave, "START SLAVE", false))
   {
     my_printf_error(0, _("Error: Unable to start slave"), MYF(0));
     return 1;
   }
+  drizzle_result_free(&slave);
   return(0);
 }
 
 
 
-static int do_flush_tables_read_lock(DRIZZLE *drizzle_con)
+static int do_flush_tables_read_lock(drizzle_con_st *drizzle_con)
 {
   /*
     We do first a FLUSH TABLES. If a long update is running, the FLUSH TABLES
@@ -2798,30 +2879,29 @@
     update starts between the two FLUSHes, we have that bad stall.
   */
   return
-    ( drizzleclient_query_with_error_report(drizzle_con, 0, "FLUSH TABLES") ||
+    ( drizzleclient_query_with_error_report(drizzle_con, 0, "FLUSH TABLES", false) ||
       drizzleclient_query_with_error_report(drizzle_con, 0,
-                                    "FLUSH TABLES WITH READ LOCK") );
+                                    "FLUSH TABLES WITH READ LOCK", false) );
 }
 
 
-static int do_unlock_tables(DRIZZLE *drizzle_con)
+static int do_unlock_tables(drizzle_con_st *drizzle_con)
 {
-  return drizzleclient_query_with_error_report(drizzle_con, 0, "UNLOCK TABLES");
+  return drizzleclient_query_with_error_report(drizzle_con, 0, "UNLOCK TABLES", false);
 }
 
-static int get_bin_log_name(DRIZZLE *drizzle_con,
+static int get_bin_log_name(drizzle_con_st *drizzle_con,
                             char* buff_log_name, uint32_t buff_len)
 {
-  drizzle_result_st *res;
+  drizzle_result_st res;
   drizzle_row_t row;
 
-  if (drizzleclient_query(drizzle_con, "SHOW MASTER STATUS") ||
-      !(res= drizzleclient_store_result(drizzle)))
+  if (drizzleclient_query_with_error_report(drizzle_con, &res, "SHOW MASTER STATUS", false))
     return 1;
 
-  if (!(row= drizzleclient_fetch_row(res)))
+  if (!(row= drizzle_row_next(&res)))
   {
-    drizzleclient_free_result(res);
+    drizzle_result_free(&res);
     return 1;
   }
   /*
@@ -2830,29 +2910,34 @@
   */
   strncpy(buff_log_name, row[0], buff_len - 1);
 
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
   return 0;
 }
 
-static int purge_bin_logs_to(DRIZZLE *drizzle_con, char* log_name)
+static int purge_bin_logs_to(drizzle_con_st *drizzle_con, char* log_name)
 {
   int err;
   string str= "PURGE BINARY LOGS TO '";
   str.append(log_name);
   str.append("'");
-  err = drizzleclient_query_with_error_report(drizzle_con, 0, str.c_str());
-  return err;
+  drizzle_result_st res;
+  err= drizzleclient_query_with_error_report(drizzle_con, &res, str.c_str(),
+                                             false);
+  if (err)
+    return err;
+  drizzle_result_free(&res);
+  return 0;
 }
 
 
-static int start_transaction(DRIZZLE *drizzle_con)
+static int start_transaction(drizzle_con_st *drizzle_con)
 {
   return (drizzleclient_query_with_error_report(drizzle_con, 0,
                                         "SET SESSION TRANSACTION ISOLATION "
-                                        "LEVEL REPEATABLE READ") ||
+                                        "LEVEL REPEATABLE READ", false) ||
           drizzleclient_query_with_error_report(drizzle_con, 0,
                                         "START TRANSACTION "
-                                        "WITH CONSISTENT SNAPSHOT"));
+                                        "WITH CONSISTENT SNAPSHOT", false));
 }
 
 
@@ -2902,12 +2987,12 @@
                         const char *prefix, const char *name,
                         int string_value)
 {
-  DRIZZLE_FIELD   *field;
-  drizzleclient_field_seek(result, 0);
+  drizzle_column_st *column;
+  drizzle_column_seek(result, 0);
 
-  for ( ; (field= drizzleclient_fetch_field(result)) ; row++)
+  for ( ; (column= drizzle_column_next(result)) ; row++)
   {
-    if (!strcmp(field->name,name))
+    if (!strcmp(drizzle_column_name(column),name))
     {
       if (row[0] && row[0][0] && strcmp(row[0],"0")) /* Skip default */
       {
@@ -2932,20 +3017,21 @@
 
 static const char* fetch_named_row(drizzle_result_st *result, drizzle_row_t row, const char *name)
 {
-  DRIZZLE_FIELD   *field;
-  drizzleclient_field_seek(result, 0);
-  for ( ; (field= drizzleclient_fetch_field(result)) ; row++)
+  drizzle_column_st *column;
+  drizzle_column_seek(result, 0);
+
+  for ( ; (column= drizzle_column_next(result)) ; row++)
   {
-    if (!strcmp(field->name,name))
+    if (!strcmp(drizzle_column_name(column),name))
     {
       if (row[0] && row[0][0] && strcmp(row[0],"0")) /* Skip default */
       {
-        drizzleclient_field_seek(result, 0);
+        drizzle_column_seek(result, 0);
         return row[0];
       }
     }
   }
-  drizzleclient_field_seek(result, 0);
+  drizzle_column_seek(result, 0);
   return NULL;
 }
 
@@ -2979,33 +3065,28 @@
   char result= IGNORE_NONE;
   char buff[FN_REFLEN+80], show_name_buff[FN_REFLEN];
   const char *number_of_rows= NULL;
-  drizzle_result_st *res= NULL;
+  drizzle_result_st res;
   drizzle_row_t row;
 
   /* Check memory for quote_for_like() */
   assert(2*sizeof(table_name) < sizeof(show_name_buff));
   snprintf(buff, sizeof(buff), "show table status like %s",
            quote_for_like(table_name, show_name_buff));
-  if (drizzleclient_query_with_error_report(drizzle, &res, buff))
+  if (drizzleclient_query_with_error_report(&dcon, &res, buff, false))
   {
-    if (drizzleclient_errno(drizzle) != ER_PARSE_ERROR)
-    {                                   /* If old DRIZZLE version */
-      verbose_msg(_("-- Warning: Couldn't get status information for "
-                  "table %s (%s)\n"), table_name, drizzleclient_error(drizzle));
-      return(result);                       /* assume table is ok */
-    }
+    return result;
   }
-  if (!(row= drizzleclient_fetch_row(res)))
+  if (!(row= drizzle_row_next(&res)))
   {
     fprintf(stderr,
-            _("Error: Couldn't read status information for table %s (%s)\n"),
-            table_name, drizzleclient_error(drizzle));
-    drizzleclient_free_result(res);
+            _("Error: Couldn't read status information for table %s\n"),
+            table_name);
+    drizzle_result_free(&res);
     return(result);                         /* assume table is ok */
   }
   else
   {
-    if ((number_of_rows= fetch_named_row(res, row, "Rows")) != NULL)
+    if ((number_of_rows= fetch_named_row(&res, row, "Rows")) != NULL)
     {
       total_rows= strtoul(number_of_rows, NULL, 10);
     }
@@ -3017,7 +3098,7 @@
     the table type is _NOT_ one of these types
     */
   {
-    strncpy(table_type, row[1], NAME_LEN-1);
+    strncpy(table_type, row[1], DRIZZLE_MAX_TABLE_SIZE-1);
     if (opt_delayed)
     {
       if (strcmp(table_type,"MyISAM") &&
@@ -3027,7 +3108,7 @@
         result= IGNORE_INSERT_DELAYED;
     }
   }
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
   return(result);
 }
 
@@ -3052,25 +3133,44 @@
 
 static char *primary_key_fields(const char *table_name)
 {
-  drizzle_result_st  *res= NULL;
+  drizzle_result_st res;
+  drizzle_return_t ret;
   drizzle_row_t  row;
   /* SHOW KEYS FROM + table name * 2 (escaped) + 2 quotes + \0 */
-  char show_keys_buff[15 + NAME_LEN * 2 + 3];
+  char show_keys_buff[15 + DRIZZLE_MAX_TABLE_SIZE * 2 + 3];
   uint32_t result_length= 0;
   char *result= 0;
-  char buff[NAME_LEN * 2 + 3];
+  char buff[DRIZZLE_MAX_TABLE_SIZE * 2 + 3];
   char *quoted_field;
 
   snprintf(show_keys_buff, sizeof(show_keys_buff),
            "SHOW KEYS FROM %s", table_name);
-  if (drizzleclient_query(drizzle, show_keys_buff) ||
-      !(res= drizzleclient_store_result(drizzle)))
+  if (drizzle_query_str(&dcon, &res, show_keys_buff, &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      fprintf(stderr, _("Warning: Couldn't read keys from table %s;"
+              " records are NOT sorted (%s)\n"),
+              table_name, drizzle_result_error(&res));
+      drizzle_result_free(&res);
+    }
+    else
+    {
+      fprintf(stderr, _("Warning: Couldn't read keys from table %s;"
+              " records are NOT sorted (%s)\n"),
+              table_name, drizzle_con_error(&dcon));
+    }
+
+    return result;
+  }
+
+  if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
   {
     fprintf(stderr, _("Warning: Couldn't read keys from table %s;"
             " records are NOT sorted (%s)\n"),
-            table_name, drizzleclient_error(drizzle));
-    /* Don't exit, because it's better to print out unsorted records */
-    goto cleanup;
+            table_name, drizzle_con_error(&dcon));
+    return result;
   }
 
   /*
@@ -3079,14 +3179,14 @@
    * row, and UNIQUE keys come before others.  So we only need to check
    * the first key, not all keys.
    */
-  if ((row= drizzleclient_fetch_row(res)) && atoi(row[1]) == 0)
+  if ((row= drizzle_row_next(&res)) && atoi(row[1]) == 0)
   {
     /* Key is unique */
     do
     {
       quoted_field= quote_name(row[4], buff, 0);
       result_length+= strlen(quoted_field) + 1; /* + 1 for ',' or \0 */
-    } while ((row= drizzleclient_fetch_row(res)) && atoi(row[3]) > 1);
+    } while ((row= drizzle_row_next(&res)) && atoi(row[3]) > 1);
   }
 
   /* Build the ORDER BY clause result */
@@ -3098,23 +3198,21 @@
     if (!result)
     {
       fprintf(stderr, _("Error: Not enough memory to store ORDER BY clause\n"));
-      goto cleanup;
+      drizzle_result_free(&res);
+      return result;
     }
-    drizzleclient_data_seek(res, 0);
-    row= drizzleclient_fetch_row(res);
+    drizzle_row_seek(&res, 0);
+    row= drizzle_row_next(&res);
     quoted_field= quote_name(row[4], buff, 0);
     end= strcpy(result, quoted_field) + strlen(quoted_field);
-    while ((row= drizzleclient_fetch_row(res)) && atoi(row[3]) > 1)
+    while ((row= drizzle_row_next(&res)) && atoi(row[3]) > 1)
     {
       quoted_field= quote_name(row[4], buff, 0);
       end+= sprintf(end,",%s",quoted_field);
     }
   }
 
-cleanup:
-  if (res)
-    drizzleclient_free_result(res);
-
+  drizzle_result_free(&res);
   return result;
 }
 
@@ -3124,6 +3222,7 @@
   char bin_log_name[FN_REFLEN];
   int exit_code;
   MY_INIT("drizzledump");
+  drizzle_result_st result;
 
   compatible_mode_normal_str[0]= 0;
   default_charset= (char *)drizzle_universal_client_charset;
@@ -3144,35 +3243,38 @@
   if (!path)
     write_header(md_result_file, *argv);
 
-  if (opt_slave_data && do_stop_slave_sql(drizzle))
+  if (opt_slave_data && do_stop_slave_sql(&dcon))
     goto err;
 
   if ((opt_lock_all_tables || opt_master_data) &&
-      do_flush_tables_read_lock(drizzle))
+      do_flush_tables_read_lock(&dcon))
     goto err;
-  if (opt_single_transaction && start_transaction(drizzle))
+  if (opt_single_transaction && start_transaction(&dcon))
       goto err;
   if (opt_delete_master_logs)
   {
-    if (drizzleclient_real_query(drizzle, "FLUSH LOGS", strlen("FLUSH LOGS")) ||
-        get_bin_log_name(drizzle, bin_log_name, sizeof(bin_log_name)))
+    if (drizzleclient_query_with_error_report(&dcon, &result, "FLUSH LOGS", false))
+      goto err;
+    drizzle_result_free(&result);
+    if (get_bin_log_name(&dcon, bin_log_name, sizeof(bin_log_name)))
       goto err;
     flush_logs= 0;
   }
   if (opt_lock_all_tables || opt_master_data)
   {
-    if (drizzleclient_real_query(drizzle, "FLUSH LOGS", strlen("FLUSH LOGS")))
+    if (drizzleclient_query_with_error_report(&dcon, &result, "FLUSH LOGS", false))
       goto err;
+    drizzle_result_free(&result);
     flush_logs= 0; /* not anymore; that would not be sensible */
   }
   /* Add 'STOP SLAVE to beginning of dump */
   if (opt_slave_apply && add_stop_slave())
     goto err;
-  if (opt_master_data && do_show_master_status(drizzle))
-    goto err;
-  if (opt_slave_data && do_show_slave_status(drizzle))
-    goto err;
-  if (opt_single_transaction && do_unlock_tables(drizzle)) /* unlock but no commit! */
+  if (opt_master_data && do_show_master_status(&dcon))
+    goto err;
+  if (opt_slave_data && do_show_slave_status(&dcon))
+    goto err;
+  if (opt_single_transaction && do_unlock_tables(&dcon)) /* unlock but no commit! */
     goto err;
 
   if (opt_alldbs)
@@ -3190,7 +3292,7 @@
   }
 
   /* if --dump-slave , start the slave sql thread */
-  if (opt_slave_data && do_start_slave_sql(drizzle))
+  if (opt_slave_data && do_start_slave_sql(&dcon))
     goto err;
 
   /* add 'START SLAVE' to end of dump */
@@ -3205,7 +3307,7 @@
     goto err;
   }
   /* everything successful, purge the old logs files */
-  if (opt_delete_master_logs && purge_bin_logs_to(drizzle, bin_log_name))
+  if (opt_delete_master_logs && purge_bin_logs_to(&dcon, bin_log_name))
     goto err;
 
   /*

=== modified file 'client/drizzleimport.cc'
--- client/drizzleimport.cc	2009-03-10 00:31:09 +0000
+++ client/drizzleimport.cc	2009-03-25 08:02:36 +0000
@@ -41,8 +41,8 @@
 pthread_mutex_t counter_mutex;
 pthread_cond_t count_threshhold;
 
-static void db_error_with_table(DRIZZLE *drizzle, char *table);
-static void db_error(DRIZZLE *drizzle);
+static void db_error(drizzle_con_st *con, drizzle_result_st *result,
+                     drizzle_return_t ret, char *table);
 static char *field_escape(char *to,const char *from,uint32_t length);
 static char *add_load_option(char *ptr,const char *object,
            const char *statement);
@@ -58,7 +58,6 @@
     *lines_terminated= NULL, *enclosed= NULL, *opt_enclosed= NULL,
     *escaped= NULL, *opt_columns= NULL,
     *default_charset= (char*) DRIZZLE_DEFAULT_CHARSET_NAME;
-static uint32_t opt_protocol= 0;
 static uint32_t opt_drizzle_port= 0;
 static char * opt_drizzle_unix_port= 0;
 static int64_t opt_ignore_lines= -1;
@@ -159,7 +158,7 @@
 static void print_version(void)
 {
   printf("%s  Ver %s Distrib %s, for %s (%s)\n" ,my_progname,
-    IMPORT_VERSION, drizzleclient_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
+    IMPORT_VERSION, drizzle_version(),SYSTEM_TYPE,MACHINE_TYPE);
 }
 
 
@@ -281,16 +280,18 @@
   current_db= *((*argv)++);
   (*argc)--;
   if (tty_password)
-    opt_password=drizzleclient_get_tty_password(NULL);
+    opt_password=client_get_tty_password(NULL);
   return(0);
 }
 
 
 
-static int write_to_table(char *filename, DRIZZLE *drizzle)
+static int write_to_table(char *filename, drizzle_con_st *con)
 {
   char tablename[FN_REFLEN], hard_path[FN_REFLEN],
        sql_statement[FN_REFLEN*16+256], *end;
+  drizzle_result_st result;
+  drizzle_return_t ret;
 
   fn_format(tablename, filename, "", "", 1 | 2); /* removes path & ext. */
   if (!opt_local_file)
@@ -307,11 +308,13 @@
 #else
     sprintf(sql_statement, "DELETE FROM %s", tablename);
 #endif
-    if (drizzleclient_query(drizzle, sql_statement))
+    if (drizzle_query_str(con, &result, sql_statement, &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
     {
-      db_error_with_table(drizzle, tablename);
+      db_error(con, &result, ret, tablename);
       return(1);
     }
+    drizzle_result_free(&result);
   }
   if (verbose)
   {
@@ -355,29 +358,32 @@
   }
   *end= '\0';
 
-  if (drizzleclient_query(drizzle, sql_statement))
+  if (drizzle_query_str(con, &result, sql_statement, &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
   {
-    db_error_with_table(drizzle, tablename);
+    db_error(con, &result, ret, tablename);
     return(1);
   }
   if (!silent)
   {
-    if (drizzleclient_info(drizzle)) /* If NULL-pointer, print nothing */
+    if (strcmp(drizzle_result_info(&result), ""))
     {
       fprintf(stdout, "%s.%s: %s\n", current_db, tablename,
-        drizzleclient_info(drizzle));
+        drizzle_result_info(&result));
     }
   }
+  drizzle_result_free(&result);
   return(0);
 }
 
 
-
-static void lock_table(DRIZZLE *drizzle, int tablecount, char **raw_tablename)
+static void lock_table(drizzle_con_st *con, int tablecount, char **raw_tablename)
 {
   string query;
   int i;
   char tablename[FN_REFLEN];
+  drizzle_result_st result;
+  drizzle_return_t ret;
 
   if (verbose)
     fprintf(stdout, "Locking tables for write\n");
@@ -388,78 +394,87 @@
     query.append(tablename);
     query.append(" WRITE,");
   }
-  if (drizzleclient_real_query(drizzle, query.c_str(), query.length()-1))
-    db_error(drizzle); /* We shall countinue here, if --force was given */
+  if (drizzle_query(con, &result, query.c_str(), query.length()-1,
+                    &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
+  {
+    db_error(con, &result, ret, NULL);
+    /* We shall countinue here, if --force was given */
+    return;
+  }
+  drizzle_result_free(&result);
 }
 
 
-
-
-static DRIZZLE *db_connect(char *host, char *database,
-                         char *user, char *passwd)
+static drizzle_con_st *db_connect(char *host, char *database,
+                                  char *user, char *passwd)
 {
-  DRIZZLE *drizzle;
+  drizzle_st *drizzle;
+  drizzle_con_st *con;
+  drizzle_return_t ret;
+
   if (verbose)
     fprintf(stdout, "Connecting to %s\n", host ? host : "localhost");
-  if (!(drizzle= drizzleclient_create(NULL)))
-    return 0;
-  if (opt_compress)
-    drizzleclient_options(drizzle,DRIZZLE_OPT_COMPRESS,NULL);
-  if (opt_protocol)
-    drizzleclient_options(drizzle,DRIZZLE_OPT_PROTOCOL,(char*)&opt_protocol);
-  if (!(drizzleclient_connect(drizzle,host,user,passwd,
-                           database,opt_drizzle_port,opt_drizzle_unix_port,
-                           0)))
+  if (!(drizzle= drizzle_create(NULL)))
+    return 0;
+  if (!(con= drizzle_con_add_tcp(drizzle,NULL,host,opt_drizzle_port,user,passwd,
+                                 database, DRIZZLE_CON_NONE)))
+  {
+    return 0;
+  }
+
+  if ((ret= drizzle_con_connect(con)) != DRIZZLE_RETURN_OK)
   {
     ignore_errors=0;    /* NO RETURN FROM db_error */
-    db_error(drizzle);
+    db_error(con, NULL, ret, NULL);
   }
-  drizzle->reconnect= 0;
+
   if (verbose)
     fprintf(stdout, "Selecting database %s\n", database);
-  if (drizzleclient_select_db(drizzle, database))
-  {
-    ignore_errors=0;
-    db_error(drizzle);
-  }
-  return drizzle;
+
+  return con;
 }
 
 
 
-static void db_disconnect(char *host, DRIZZLE *drizzle)
+static void db_disconnect(char *host, drizzle_con_st *con)
 {
   if (verbose)
     fprintf(stdout, "Disconnecting from %s\n", host ? host : "localhost");
-  drizzleclient_close(drizzle);
+  drizzle_free(drizzle_con_drizzle(con));
 }
 
 
 
-static void safe_exit(int error, DRIZZLE *drizzle)
+static void safe_exit(int error, drizzle_con_st *con)
 {
   if (ignore_errors)
     return;
-  if (drizzle)
-    drizzleclient_close(drizzle);
+  if (con)
+    drizzle_free(drizzle_con_drizzle(con));
   exit(error);
 }
 
 
 
-static void db_error_with_table(DRIZZLE *drizzle, char *table)
-{
-  my_printf_error(0,"Error: %d, %s, when using table: %s",
-      MYF(0), drizzleclient_errno(drizzle), drizzleclient_error(drizzle), table);
-  safe_exit(1, drizzle);
-}
-
-
-
-static void db_error(DRIZZLE *drizzle)
-{
-  my_printf_error(0,"Error: %d %s", MYF(0), drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
-  safe_exit(1, drizzle);
+static void db_error(drizzle_con_st *con, drizzle_result_st *result,
+                     drizzle_return_t ret, char *table)
+{
+  if (ret == DRIZZLE_RETURN_ERROR_CODE)
+  {
+    my_printf_error(0,"Error: %d, %s%s%s", MYF(0),
+                    drizzle_result_error_code(result),
+                    drizzle_result_error(result),
+                    table ? ", when using table: " : "", table ? table : "");
+    drizzle_result_free(result);
+  }
+  else
+  {
+    my_printf_error(0,"Error: %d, %s%s%s", MYF(0), ret, drizzle_con_error(con),
+                    table ? ", when using table: " : "", table ? table : "");
+  }
+
+  safe_exit(1, con);
 }
 
 
@@ -519,29 +534,35 @@
 {
   int error;
   char *raw_table_name= (char *)arg;
-  DRIZZLE *drizzle= 0;
+  drizzle_con_st *con= NULL;
+  drizzle_result_st result;
+  drizzle_return_t ret;
 
-  if (!(drizzle= db_connect(current_host,current_db,current_user,opt_password)))
+  if (!(con= db_connect(current_host,current_db,current_user,opt_password)))
   {
     goto error;
   }
 
-  if (drizzleclient_query(drizzle, "/*!40101 set @@character_set_database=binary */;"))
+  if (drizzle_query_str(con, &result,
+                        "/*!40101 set @@character_set_database=binary */;",
+                        &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
   {
-    db_error(drizzle); /* We shall countinue here, if --force was given */
+    db_error(con, &result, ret, NULL);
+    /* We shall countinue here, if --force was given */
     goto error;
   }
 
   /*
     We are not currently catching the error here.
   */
-  if((error= write_to_table(raw_table_name, drizzle)))
+  if((error= write_to_table(raw_table_name, con)))
     if (exitcode == 0)
       exitcode= error;
 
 error:
-  if (drizzle)
-    db_disconnect(current_host, drizzle);
+  if (con)
+    db_disconnect(current_host, con);
 
   pthread_mutex_lock(&counter_mutex);
   counter--;
@@ -624,26 +645,34 @@
   else
 #endif
   {
-    DRIZZLE *drizzle= 0;
-    if (!(drizzle= db_connect(current_host,current_db,current_user,opt_password)))
+    drizzle_con_st *con= 0;
+    drizzle_result_st result;
+    drizzle_return_t ret;
+    if (!(con= db_connect(current_host,current_db,current_user,opt_password)))
     {
       free_defaults(argv_to_free);
       return(1); /* purecov: deadcode */
     }
 
-    if (drizzleclient_query(drizzle, "/*!40101 set @@character_set_database=binary */;"))
+    if (drizzle_query_str(con, &result,
+                          "/*!40101 set @@character_set_database=binary */;",
+                          &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
     {
-      db_error(drizzle); /* We shall countinue here, if --force was given */
+      db_error(con, &result, ret, NULL);
+      /* We shall countinue here, if --force was given */
       return(1);
     }
 
+    drizzle_result_free(&result);
+
     if (lock_tables)
-      lock_table(drizzle, argc, argv);
+      lock_table(con, argc, argv);
     for (; *argv != NULL; argv++)
-      if ((error= write_to_table(*argv, drizzle)))
+      if ((error= write_to_table(*argv, con)))
         if (exitcode == 0)
           exitcode= error;
-    db_disconnect(current_host, drizzle);
+    db_disconnect(current_host, con);
   }
   free(opt_password);
   free_defaults(argv_to_free);

=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2009-03-10 02:20:19 +0000
+++ client/drizzletest.cc	2009-03-25 08:02:36 +0000
@@ -192,9 +192,10 @@
 
 struct st_connection
 {
-  DRIZZLE drizzle;
+  drizzle_st drizzle;
+  drizzle_con_st con;
   /* Used when creating views and sp, to avoid implicit commit */
-  DRIZZLE *util_drizzle;
+  drizzle_con_st *util_con;
   char *name;
 };
 struct st_connection connections[128];
@@ -351,7 +352,7 @@
   union
   {
     uint32_t errnum;
-    char sqlstate[SQLSTATE_LENGTH+1];  /* \0 terminated string */
+    char sqlstate[DRIZZLE_MAX_SQLSTATE_SIZE+1];  /* \0 terminated string */
   } code;
 };
 
@@ -444,8 +445,6 @@
 void handle_no_error(struct st_command*);
 
 
-#define do_send_query(cn,q,q_len,flags) drizzleclient_send_query(&cn->drizzle, q, q_len)
-
 void do_eval(string *query_eval, const char *query,
              const char *query_end, bool pass_through_escape_chars)
 {
@@ -559,45 +558,58 @@
 
 */
 
-static void show_query(DRIZZLE *drizzle, const char* query)
+static void show_query(drizzle_con_st *con, const char* query)
 {
-  DRIZZLE_RES* res;
-
-
-  if (!drizzle)
+  drizzle_result_st res;
+  drizzle_return_t ret;
+
+  if (!con)
     return;
 
-  if (drizzleclient_query(drizzle, query))
+  if (drizzle_query_str(con, &res, query, &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
   {
-    log_msg("Error running query '%s': %d %s",
-            query, drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      log_msg("Error running query '%s': %d %s",
+              query, drizzle_result_error_code(&res),
+              drizzle_result_error(&res));
+      drizzle_result_free(&res);
+    }
+    else
+    {
+      log_msg("Error running query '%s': %d %s",
+              query, ret, drizzle_con_error(con));
+    }
     return;
   }
 
-  if ((res= drizzleclient_store_result(drizzle)) == NULL)
+  if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
   {
     /* No result set returned */
     return;
   }
 
   {
-    DRIZZLE_ROW row;
+    drizzle_row_t row;
     unsigned int i;
     unsigned int row_num= 0;
-    unsigned int num_fields= drizzleclient_num_fields(res);
-    const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
+    unsigned int num_fields= drizzle_result_column_count(&res);
+    drizzle_column_st *column;
 
     fprintf(stderr, "=== %s ===\n", query);
-    while ((row= drizzleclient_fetch_row(res)))
+    while ((row= drizzle_row_next(&res)))
     {
-      uint32_t *lengths= drizzleclient_fetch_lengths(res);
+      size_t *lengths= drizzle_row_field_sizes(&res);
       row_num++;
 
       fprintf(stderr, "---- %d. ----\n", row_num);
+      drizzle_column_seek(&res, 0);
       for(i= 0; i < num_fields; i++)
       {
+        column= drizzle_column_next(&res);
         fprintf(stderr, "%s\t%.*s\n",
-                fields[i].name,
+                drizzle_column_name(column),
                 (int)lengths[i], row[i] ? row[i] : "NULL");
       }
     }
@@ -605,7 +617,7 @@
       fprintf(stderr, "=");
     fprintf(stderr, "\n\n");
   }
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
 
   return;
 }
@@ -624,45 +636,56 @@
 
 */
 
-static void show_warnings_before_error(DRIZZLE *drizzle)
+static void show_warnings_before_error(drizzle_con_st *con)
 {
-  DRIZZLE_RES* res;
+  drizzle_result_st res;
+  drizzle_return_t ret;
   const char* query= "SHOW WARNINGS";
 
-
-  if (!drizzle)
+  if (!con)
     return;
 
-  if (drizzleclient_query(drizzle, query))
+  if (drizzle_query_str(con, &res, query, &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
   {
-    log_msg("Error running query '%s': %d %s",
-            query, drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      log_msg("Error running query '%s': %d %s",
+              query, drizzle_result_error_code(&res),
+              drizzle_result_error(&res));
+      drizzle_result_free(&res);
+    }
+    else
+    {
+      log_msg("Error running query '%s': %d %s",
+              query, ret, drizzle_con_error(con));
+    }
     return;
   }
 
-  if ((res= drizzleclient_store_result(drizzle)) == NULL)
+  if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
   {
     /* No result set returned */
     return;
   }
 
-  if (drizzleclient_num_rows(res) <= 1)
+  if (drizzle_result_row_count(&res) <= 1)
   {
     /* Don't display the last row, it's "last error" */
   }
   else
   {
-    DRIZZLE_ROW row;
+    drizzle_row_t row;
     unsigned int row_num= 0;
-    unsigned int num_fields= drizzleclient_num_fields(res);
+    unsigned int num_fields= drizzle_result_column_count(&res);
 
     fprintf(stderr, "\nWarnings from just before the error:\n");
-    while ((row= drizzleclient_fetch_row(res)))
+    while ((row= drizzle_row_next(&res)))
     {
       uint32_t i;
-      uint32_t *lengths= drizzleclient_fetch_lengths(res);
+      size_t *lengths= drizzle_row_field_sizes(&res);
 
-      if (++row_num >= drizzleclient_num_rows(res))
+      if (++row_num >= drizzle_result_row_count(&res))
       {
         /* Don't display the last row, it's "last error" */
         break;
@@ -676,7 +699,7 @@
       fprintf(stderr, "\n");
     }
   }
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
 
   return;
 }
@@ -802,12 +825,9 @@
 
 static void close_connections(void)
 {
-
   for (--next_con; next_con >= connections; --next_con)
   {
-    drizzleclient_close(&next_con->drizzle);
-    if (next_con->util_drizzle)
-      drizzleclient_close(next_con->util_drizzle);
+    drizzle_free(&next_con->drizzle);
     free(next_con->name);
   }
   return;
@@ -954,7 +974,7 @@
     been produced prior to the error
   */
   if (cur_con)
-    show_warnings_before_error(&cur_con->drizzle);
+    show_warnings_before_error(&cur_con->con);
 
   cleanup_and_exit(1);
 }
@@ -1770,9 +1790,9 @@
   of the currently connected server
 */
 
-static void var_set_drizzleclient_get_server_version(DRIZZLE *drizzle)
+static void var_set_drizzleclient_get_server_version(drizzle_con_st *con)
 {
-  var_set_int("$drizzleclient_get_server_version", drizzleclient_get_server_version(drizzle));
+  var_set_int("$drizzle_con_server_version", drizzle_con_server_version_number(con));
 }
 
 
@@ -1803,9 +1823,10 @@
 {
   const char *end = (char*)((query_end && *query_end) ?
                             *query_end : query + strlen(query));
-  DRIZZLE_RES *res;
-  DRIZZLE_ROW row;
-  DRIZZLE *drizzle= &cur_con->drizzle;
+  drizzle_result_st res;
+  drizzle_return_t ret;
+  drizzle_row_t row;
+  drizzle_con_st *con= &cur_con->con;
   string ds_query;
 
 
@@ -1818,13 +1839,26 @@
   /* Eval the query, thus replacing all environment variables */
   do_eval(&ds_query, query, end, false);
 
-  if (drizzleclient_real_query(drizzle, ds_query.c_str(), ds_query.length()))
-    die("Error running query '%s': %d %s", ds_query.c_str(),
-        drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
-  if (!(res= drizzleclient_store_result(drizzle)))
+  if (drizzle_query(con, &res, ds_query.c_str(), ds_query.length(),
+                    &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      die("Error running query '%s': %d %s", ds_query.c_str(),
+          drizzle_result_error_code(&res), drizzle_result_error(&res));
+      drizzle_result_free(&res);
+    }
+    else
+    {
+      die("Error running query '%s': %d %s", ds_query.c_str(), ret,
+          drizzle_con_error(con));
+    }
+  }
+  if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
     die("Query '%s' didn't return a result set", ds_query.c_str());
 
-  if ((row= drizzleclient_fetch_row(res)) && row[0])
+  if ((row= drizzle_row_next(&res)) && row[0])
   {
     /*
       Concatenate all fields in the first row with tab in between
@@ -1832,10 +1866,10 @@
     */
     string result;
     uint32_t i;
-    uint32_t *lengths;
+    size_t *lengths;
 
-    lengths= drizzleclient_fetch_lengths(res);
-    for (i= 0; i < drizzleclient_num_fields(res); i++)
+    lengths= drizzle_row_field_sizes(&res);
+    for (i= 0; i < drizzle_result_column_count(&res); i++)
     {
       if (row[i])
       {
@@ -1850,7 +1884,7 @@
   else
     eval_expr(var, "", 0);
 
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
   return;
 }
 
@@ -1881,8 +1915,9 @@
 {
   long row_no;
   int col_no= -1;
-  DRIZZLE_RES* res;
-  DRIZZLE *drizzle= &cur_con->drizzle;
+  drizzle_result_st res;
+  drizzle_return_t ret;
+  drizzle_con_st *con= &cur_con->con;
 
   string ds_query;
   string ds_col;
@@ -1913,22 +1948,36 @@
   ds_query.append(unstripped_query);
 
   /* Run the query */
-  if (drizzleclient_real_query(drizzle, ds_query.c_str(), ds_query.length()))
-    die("Error running query '%s': %d %s", ds_query.c_str(),
-        drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
-  if (!(res= drizzleclient_store_result(drizzle)))
+  if (drizzle_query(con, &res, ds_query.c_str(), ds_query.length(),
+                    &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      die("Error running query '%s': %d %s", ds_query.c_str(),
+          drizzle_result_error_code(&res), drizzle_result_error(&res));
+      drizzle_result_free(&res);
+    }
+    else
+    {
+      die("Error running query '%s': %d %s", ds_query.c_str(), ret,
+          drizzle_con_error(con));
+    }
+  }
+  if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
     die("Query '%s' didn't return a result set", ds_query.c_str());
 
   {
     /* Find column number from the given column name */
     uint32_t i;
-    uint32_t num_fields= drizzleclient_num_fields(res);
-    const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
+    uint32_t num_fields= drizzle_result_column_count(&res);
+    drizzle_column_st *column;
 
     for (i= 0; i < num_fields; i++)
     {
-      if (strcmp(fields[i].name, ds_col.c_str()) == 0 &&
-          strlen(fields[i].name) == ds_col.length())
+      column= drizzle_column_next(&res);
+      if (strcmp(drizzle_column_name(column), ds_col.c_str()) == 0 &&
+          strlen(drizzle_column_name(column)) == ds_col.length())
       {
         col_no= i;
         break;
@@ -1936,7 +1985,7 @@
     }
     if (col_no == -1)
     {
-      drizzleclient_free_result(res);
+      drizzle_result_free(&res);
       die("Could not find column '%s' in the result of '%s'",
           ds_col.c_str(), ds_query.c_str());
     }
@@ -1944,11 +1993,11 @@
 
   {
     /* Get the value */
-    DRIZZLE_ROW row;
+    drizzle_row_t row;
     long rows= 0;
     const char* value= "No such row";
 
-    while ((row= drizzleclient_fetch_row(res)))
+    while ((row= drizzle_row_next(&res)))
     {
       if (++rows == row_no)
       {
@@ -1964,7 +2013,7 @@
     }
     eval_expr(var, value, 0);
   }
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
 
   return;
 }
@@ -2809,6 +2858,8 @@
 {
   char *p= command->first_argument, *name;
   struct st_connection *con;
+  drizzle_result_st result;
+  drizzle_return_t ret;
 
   if (!*p)
     die("Missing connection name in send_quit");
@@ -2823,7 +2874,8 @@
   if (!(con= find_connection_by_name(name)))
     die("connection '%s' not found in connection pool", name);
 
-  simple_command(&con->drizzle,COM_QUIT,0,0,1);
+  if (drizzle_quit(&con->con,&result, &ret))
+    drizzle_result_free(&result);
 
   return;
 }
@@ -2968,24 +3020,43 @@
 do_wait_for_slave_to_stop(struct st_command *)
 {
   static int SLAVE_POLL_INTERVAL= 300000;
-  DRIZZLE *drizzle= &cur_con->drizzle;
+  drizzle_con_st *con= &cur_con->con;
   for (;;)
   {
-    DRIZZLE_RES *res= NULL;
-    DRIZZLE_ROW row;
+    drizzle_result_st res;
+    drizzle_return_t ret;
+    drizzle_row_t row;
     int done;
 
-    if (drizzleclient_query(drizzle,"show status like 'Slave_running'") ||
-        !(res=drizzleclient_store_result(drizzle)))
+    if (drizzle_query_str(con,&res,"show status like 'Slave_running'",
+                          &ret) == NULL || ret != DRIZZLE_RETURN_OK)
+    {
+      if (ret == DRIZZLE_RETURN_ERROR_CODE)
+      {
+        die("Query failed while probing slave for stop: %s",
+            drizzle_result_error(&res));
+        drizzle_result_free(&res);
+      }
+      else
+      {
+        die("Query failed while probing slave for stop: %s",
+            drizzle_con_error(con));
+      }
+    }
+
+    if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
+    {
       die("Query failed while probing slave for stop: %s",
-          drizzleclient_error(drizzle));
-    if (!(row=drizzleclient_fetch_row(res)) || !row[1])
+          drizzle_con_error(con));
+    }
+
+    if (!(row=drizzle_row_next(&res)) || !row[1])
     {
-      drizzleclient_free_result(res);
+      drizzle_result_free(&res);
       die("Strange result from query while probing slave for stop");
     }
     done = !strcmp(row[1],"OFF");
-    drizzleclient_free_result(res);
+    drizzle_result_free(&res);
     if (done)
       break;
     usleep(SLAVE_POLL_INTERVAL);
@@ -2996,9 +3067,10 @@
 
 static void do_sync_with_master2(long offset)
 {
-  DRIZZLE_RES *res;
-  DRIZZLE_ROW row;
-  DRIZZLE *drizzle= &cur_con->drizzle;
+  drizzle_result_st res;
+  drizzle_return_t ret;
+  drizzle_row_t row;
+  drizzle_con_st *con= &cur_con->con;
   char query_buf[FN_REFLEN+128];
   int tries= 0;
 
@@ -3010,15 +3082,25 @@
 
 wait_for_position:
 
-  if (drizzleclient_query(drizzle, query_buf))
-    die("failed in '%s': %d: %s", query_buf, drizzleclient_errno(drizzle),
-        drizzleclient_error(drizzle));
-
-  if (!(res= drizzleclient_store_result(drizzle)))
-    die("drizzleclient_store_result() returned NULL for '%s'", query_buf);
-  if (!(row= drizzleclient_fetch_row(res)))
-  {
-    drizzleclient_free_result(res);
+  if (drizzle_query_str(con, &res, query_buf, &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      die("failed in '%s': %d: %s", query_buf, drizzle_result_error_code(&res),
+           drizzle_result_error(&res));
+      drizzle_result_free(&res);
+    }
+    else
+      die("failed in '%s': %d: %s", query_buf, ret, drizzle_con_error(con));
+  }
+
+  if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
+    die("drizzle_result_buffer() returned NULL for '%s'", query_buf);
+
+  if (!(row= drizzle_row_next(&res)))
+  {
+    drizzle_result_free(&res);
     die("empty result in %s", query_buf);
   }
   if (!row[0])
@@ -3027,17 +3109,17 @@
       It may be that the slave SQL thread has not started yet, though START
       SLAVE has been issued ?
     */
-    drizzleclient_free_result(res);
+    drizzle_result_free(&res);
     if (tries++ == 30)
     {
-      show_query(drizzle, "SHOW MASTER STATUS");
-      show_query(drizzle, "SHOW SLAVE STATUS");
+      show_query(con, "SHOW MASTER STATUS");
+      show_query(con, "SHOW SLAVE STATUS");
       die("could not sync with master ('%s' returned NULL)", query_buf);
     }
     sleep(1); /* So at most we will wait 30 seconds and make 31 tries */
     goto wait_for_position;
   }
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
   return;
 }
 
@@ -3067,23 +3149,33 @@
 */
 static int do_save_master_pos(void)
 {
-  DRIZZLE_RES *res;
-  DRIZZLE_ROW row;
-  DRIZZLE *drizzle= &cur_con->drizzle;
+  drizzle_result_st res;
+  drizzle_return_t ret;
+  drizzle_row_t row;
+  drizzle_con_st *con= &cur_con->con;
   const char *query;
 
 
-  if (drizzleclient_query(drizzle, query= "show master status"))
-    die("failed in 'show master status': %d %s",
-        drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
+  if (drizzle_query_str(con, &res, query= "show master status", &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      die("failed in '%s': %d: %s", query, drizzle_result_error_code(&res),
+           drizzle_result_error(&res));
+      drizzle_result_free(&res);
+    }
+    else
+      die("failed in '%s': %d: %s", query, ret, drizzle_con_error(con));
+  }
 
-  if (!(res = drizzleclient_store_result(drizzle)))
+  if (drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
     die("drizzleclient_store_result() retuned NULL for '%s'", query);
-  if (!(row = drizzleclient_fetch_row(res)))
+  if (!(row = drizzle_row_next(&res)))
     die("empty result in show master status");
   strncpy(master_pos.file, row[0], sizeof(master_pos.file)-1);
   master_pos.pos = strtoul(row[1], (char**) 0, 10);
-  drizzleclient_free_result(res);
+  drizzle_result_free(&res);
   return(0);
 }
 
@@ -3286,12 +3378,12 @@
 
       /*
         SQLSTATE string
-        - Must be SQLSTATE_LENGTH long
+        - Must be DRIZZLE_MAX_SQLSTATE_SIZE long
         - May contain only digits[0-9] and _uppercase_ letters
       */
       p++; /* Step past the S */
-      if ((end - p) != SQLSTATE_LENGTH)
-        die("The sqlstate must be exactly %d chars long", SQLSTATE_LENGTH);
+      if ((end - p) != DRIZZLE_MAX_SQLSTATE_SIZE)
+        die("The sqlstate must be exactly %d chars long", DRIZZLE_MAX_SQLSTATE_SIZE);
 
       /* Check sqlstate string validity */
       while (*p && p < end)
@@ -3446,13 +3538,15 @@
 }
 
 
-static void set_reconnect(DRIZZLE *drizzle, int val)
+static void set_reconnect(drizzle_con_st *con, int val)
 {
+  (void) con;
+  (void) val;
+/* XXX
   bool reconnect= val;
 
   drizzleclient_options(drizzle, DRIZZLE_OPT_RECONNECT, (char *)&reconnect);
-
-  return;
+*/
 }
 
 
@@ -3462,7 +3556,7 @@
     die("connection '%s' not found in connection pool", name);
 
   /* Update $drizzleclient_get_server_version to that of current connection */
-  var_set_drizzleclient_get_server_version(&cur_con->drizzle);
+  var_set_drizzleclient_get_server_version(&cur_con->con);
 
   return(0);
 }
@@ -3504,20 +3598,7 @@
   if (!(con= find_connection_by_name(name)))
     die("connection '%s' not found in connection pool", name);
 
-  if (command->type == Q_DIRTY_CLOSE)
-  {
-    if (con->drizzle.net.vio)
-    {
-      drizzleclient_net_close(&(con->drizzle.net));
-    }
-  }
-
-  drizzleclient_close(&con->drizzle);
-
-  if (con->util_drizzle)
-    drizzleclient_close(con->util_drizzle);
-  con->util_drizzle= 0;
-
+  drizzle_free(&con->drizzle);
   free(con->name);
 
   /*
@@ -3556,16 +3637,18 @@
 
 */
 
-static void safe_connect(DRIZZLE *drizzle, const char *name, const char *host,
-                         const char *user, const char *pass, const char *db,
-                         int port)
+static void safe_connect(drizzle_con_st *con, const char *name,
+                         const char *host, const char *user, const char *pass,
+                         const char *db, int port)
 {
   int failed_attempts= 0;
   static uint32_t connection_retry_sleep= 100000; /* Microseconds */
-
-
-  while(!drizzleclient_connect(drizzle, host, user, pass, db, port, NULL,
-                         CLIENT_MULTI_STATEMENTS | CLIENT_REMEMBER_OPTIONS))
+  drizzle_return_t ret;
+
+  drizzle_con_set_tcp(con, host, port);
+  drizzle_con_set_auth(con, user, pass);
+  drizzle_con_set_db(con, db);
+  while((ret= drizzle_con_connect(con)) != DRIZZLE_RETURN_OK)
   {
     /*
       Connect failed
@@ -3575,23 +3658,22 @@
       on protocol/connection type
     */
 
-    if ((drizzleclient_errno(drizzle) == CR_CONN_HOST_ERROR ||
-         drizzleclient_errno(drizzle) == CR_CONNECTION_ERROR) &&
+    if ((ret == DRIZZLE_RETURN_GETADDRINFO ||
+         ret == DRIZZLE_RETURN_COULD_NOT_CONNECT) &&
         failed_attempts < opt_max_connect_retries)
     {
       verbose_msg("Connect attempt %d/%d failed: %d: %s", failed_attempts,
-                  opt_max_connect_retries, drizzleclient_errno(drizzle),
-                  drizzleclient_error(drizzle));
+                  opt_max_connect_retries, ret, drizzle_con_error(con));
       usleep(connection_retry_sleep);
     }
     else
     {
       if (failed_attempts > 0)
         die("Could not open connection '%s' after %d attempts: %d %s", name,
-            failed_attempts, drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
+            failed_attempts, ret, drizzle_con_error(con));
       else
-        die("Could not open connection '%s': %d %s", name,
-            drizzleclient_errno(drizzle), drizzleclient_error(drizzle));
+        die("Could not open connection '%s': %d %s", name, ret,
+            drizzle_con_error(con));
     }
     failed_attempts++;
   }
@@ -3623,10 +3705,11 @@
 */
 
 static int connect_n_handle_errors(struct st_command *command,
-                                   DRIZZLE *con, const char* host,
+                                   drizzle_con_st *con, const char* host,
                                    const char* user, const char* pass,
                                    const char* db, int port, const char* sock)
 {
+  drizzle_return_t ret;
 
   /* Only log if an error is expected */
   if (!command->abort_on_error &&
@@ -3653,12 +3736,13 @@
     ds_res.append(delimiter);
     ds_res.append("\n");
   }
-  if (!drizzleclient_connect(con, host, user, pass, db, port, 0,
-                       CLIENT_MULTI_STATEMENTS))
+  drizzle_con_set_tcp(con, host, port);
+  drizzle_con_set_auth(con, user, pass);
+  drizzle_con_set_db(con, db);
+  if ((ret= drizzle_con_connect(con)) != DRIZZLE_RETURN_OK)
   {
-    var_set_errno(drizzleclient_errno(con));
-    handle_error(command, drizzleclient_errno(con), drizzleclient_error(con),
-                 drizzleclient_sqlstate(con), &ds_res);
+    var_set_errno(ret);
+    handle_error(command, ret, drizzle_con_error(con), NULL, &ds_res);
     return 0; /* Not connected */
   }
 
@@ -3786,11 +3870,10 @@
           (int) (sizeof(connections)/sizeof(struct st_connection)));
   }
 
-  if (!drizzleclient_create(&con_slot->drizzle))
-    die("Failed on drizzleclient_create()");
-  if (opt_compress || con_compress)
-    drizzleclient_options(&con_slot->drizzle, DRIZZLE_OPT_COMPRESS, NULL);
-  
+  if (!drizzle_create(&con_slot->drizzle))
+    die("Failed on drizzle_create()");
+  if (!drizzle_con_create(&con_slot->drizzle, &con_slot->con))
+    die("Failed on drizzle_con_create()");
 
   /* Use default db name */
   if (ds_database.length() == 0)
@@ -3800,7 +3883,7 @@
   if (ds_database.length() && !strcmp(ds_database.c_str(),"*NO-ONE*"))
     ds_database.clear();
 
-  if (connect_n_handle_errors(command, &con_slot->drizzle,
+  if (connect_n_handle_errors(command, &con_slot->con,
                               ds_host.c_str(),ds_user.c_str(),
                               ds_password.c_str(), ds_database.c_str(),
                               con_port, ds_sock.c_str()))
@@ -3814,7 +3897,7 @@
   }
 
   /* Update $drizzleclient_get_server_version to that of current connection */
-  var_set_drizzleclient_get_server_version(&cur_con->drizzle);
+  var_set_drizzleclient_get_server_version(&cur_con->con);
 
   return;
 }
@@ -4499,7 +4582,7 @@
 static void print_version(void)
 {
   printf("%s  Ver %s Distrib %s, for %s (%s)\n",my_progname,MTEST_VERSION,
-         drizzleclient_get_client_info(),SYSTEM_TYPE,MACHINE_TYPE);
+         drizzle_version(),SYSTEM_TYPE,MACHINE_TYPE);
 }
 
 static void usage(void)
@@ -4685,7 +4768,7 @@
   if (argc == 1)
     opt_db= *argv;
   if (tty_password)
-    opt_pass= drizzleclient_get_tty_password(NULL);          /* purify tested */
+    opt_pass= client_get_tty_password(NULL);          /* purify tested */
   if (debug_info_flag)
     my_end_arg= MY_CHECK_ERROR | MY_GIVE_INFO;
   if (debug_check_flag)
@@ -4781,7 +4864,7 @@
   Append the result for one field to the dynamic string ds
 */
 
-static void append_field(string *ds, uint32_t col_idx, const DRIZZLE_FIELD* field,
+static void append_field(string *ds, uint32_t col_idx, drizzle_column_st *column,
                          const char* val, uint64_t len, bool is_null)
 {
   if (col_idx < max_replace_column && replace_column[col_idx])
@@ -4803,7 +4886,7 @@
   }
   else
   {
-    ds->append(field->name);
+    ds->append(drizzle_column_name(column));
     ds->append("\t");
     replace_append_mem(ds, val, (int)len);
     ds->append("\n");
@@ -4816,19 +4899,20 @@
   Values may be converted with 'replace_column'
 */
 
-static void append_result(string *ds, DRIZZLE_RES *res)
+static void append_result(string *ds, drizzle_result_st *res)
 {
-  DRIZZLE_ROW row;
-  uint32_t num_fields= drizzleclient_num_fields(res);
-  const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
-  uint32_t *lengths;
+  drizzle_row_t row;
+  uint32_t num_fields= drizzle_result_column_count(res);
+  drizzle_column_st *column;
+  size_t *lengths;
 
-  while ((row = drizzleclient_fetch_row(res)))
+  while ((row = drizzle_row_next(res)))
   {
     uint32_t i;
-    lengths = drizzleclient_fetch_lengths(res);
+    lengths = drizzle_row_field_sizes(res);
+    drizzle_column_seek(res, 0);
     for (i = 0; i < num_fields; i++)
-      append_field(ds, i, &fields[i],
+      append_field(ds, i, column,
                    (const char*)row[i], lengths[i], !row[i]);
     if (!display_result_vertically)
       ds->append("\n");
@@ -4841,49 +4925,46 @@
   Append metadata for fields to output
 */
 
-static void append_metadata(string *ds,
-                            const DRIZZLE_FIELD *field,
-                            uint32_t num_fields)
+static void append_metadata(string *ds, drizzle_result_st *res)
 {
-  const DRIZZLE_FIELD *field_end;
+  drizzle_column_st *column;
   ds->append("Catalog\tDatabase\tTable\tTable_alias\tColumn\t"
              "Column_alias\tType\tLength\tMax length\tIs_null\t"
              "Flags\tDecimals\tCharsetnr\n");
 
-  for (field_end= field+num_fields ;
-       field < field_end ;
-       field++)
+  drizzle_column_seek(res, 0);
+  while ((column= drizzle_column_next(res)))
   {
-    ds->append(field->catalog,
-               field->catalog_length);
-    ds->append("\t", 1);
-    ds->append(field->db, field->db_length);
-    ds->append("\t", 1);
-    ds->append(field->org_table,
-               field->org_table_length);
-    ds->append("\t", 1);
-    ds->append(field->table,
-               field->table_length);
-    ds->append("\t", 1);
-    ds->append(field->org_name,
-               field->org_name_length);
-    ds->append("\t", 1);
-    ds->append(field->name, field->name_length);
-    ds->append("\t", 1);
-    replace_append_uint(ds, field->type);
-    ds->append("\t", 1);
-    replace_append_uint(ds, field->length);
-    ds->append("\t", 1);
-    replace_append_uint(ds, field->max_length);
-    ds->append("\t", 1);
-    ds->append((char*) ((field->flags & NOT_NULL_FLAG) ?
-                        "N" : "Y"), 1);
-    ds->append("\t", 1);
-    replace_append_uint(ds, field->flags);
-    ds->append("\t", 1);
-    replace_append_uint(ds, field->decimals);
-    ds->append("\t", 1);
-    replace_append_uint(ds, field->charsetnr);
+    ds->append(drizzle_column_catalog(column),
+               strlen(drizzle_column_catalog(column)));
+    ds->append("\t", 1);
+    ds->append(drizzle_column_db(column), strlen(drizzle_column_db(column)));
+    ds->append("\t", 1);
+    ds->append(drizzle_column_orig_table(column),
+               strlen(drizzle_column_orig_table(column)));
+    ds->append("\t", 1);
+    ds->append(drizzle_column_table(column),
+               strlen(drizzle_column_table(column)));
+    ds->append("\t", 1);
+    ds->append(drizzle_column_orig_name(column),
+               strlen(drizzle_column_orig_name(column)));
+    ds->append("\t", 1);
+    ds->append(drizzle_column_name(column),
+               strlen(drizzle_column_name(column)));
+    ds->append("\t", 1);
+    replace_append_uint(ds, drizzle_column_type(column));
+    ds->append("\t", 1);
+    replace_append_uint(ds, drizzle_column_size(column));
+    ds->append("\t", 1);
+    replace_append_uint(ds, drizzle_column_max_size(column));
+    ds->append("\t", 1);
+    ds->append((char*) ((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_NOT_NULL) ? "N" : "Y"), 1);
+    ds->append("\t", 1);
+    replace_append_uint(ds, drizzle_column_flags(column));
+    ds->append("\t", 1);
+    replace_append_uint(ds, drizzle_column_decimals(column));
+    ds->append("\t", 1);
+    replace_append_uint(ds, drizzle_column_charset(column));
     ds->append("\n", 1);
   }
 }
@@ -4912,16 +4993,17 @@
   Display the table headings with the names tab separated
 */
 
-static void append_table_headings(string *ds,
-                                  const DRIZZLE_FIELD *field,
-                                  uint32_t num_fields)
+static void append_table_headings(string *ds, drizzle_result_st *res)
 {
-  uint32_t col_idx;
-  for (col_idx= 0; col_idx < num_fields; col_idx++)
+  uint32_t col_idx= 0;
+  drizzle_column_st *column;
+  drizzle_column_seek(res, 0);
+  while ((column= drizzle_column_next(res)))
   {
     if (col_idx)
       ds->append("\t", 1);
-    replace_append(ds, field[col_idx].name);
+    replace_append(ds, drizzle_column_name(column));
+    col_idx++;
   }
   ds->append("\n", 1);
 }
@@ -4933,30 +5015,31 @@
   Number of warnings appended to ds
 */
 
-static int append_warnings(string *ds, DRIZZLE *drizzle)
+static int append_warnings(string *ds, drizzle_con_st *con,
+                           drizzle_result_st *res)
 {
   uint32_t count;
-  DRIZZLE_RES *warn_res;
-
-
-  if (!(count= drizzleclient_warning_count(drizzle)))
+  drizzle_result_st warn_res;
+  drizzle_return_t ret;
+
+
+  if (!(count= drizzle_result_warning_count(res)))
     return(0);
 
-  /*
-    If one day we will support execution of multi-statements
-    through PS API we should not issue SHOW WARNINGS until
-    we have not read all results...
-  */
-  assert(!drizzleclient_more_results(drizzle));
-
-  if (drizzleclient_real_query(drizzle, "SHOW WARNINGS", 13))
-    die("Error running query \"SHOW WARNINGS\": %s", drizzleclient_error(drizzle));
-
-  if (!(warn_res= drizzleclient_store_result(drizzle)))
-    die("Warning count is %u but didn't get any warnings",
-        count);
-
-  append_result(ds, warn_res);
+  if (drizzle_query_str(con, &warn_res, "SHOW WARNINGS", &ret) == NULL ||
+      ret != DRIZZLE_RETURN_OK)
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+      die("Error running query \"SHOW WARNINGS\": %s", drizzle_result_error(&warn_res));
+    else
+      die("Error running query \"SHOW WARNINGS\": %s", drizzle_con_error(con));
+  }
+
+  if (drizzle_result_buffer(&warn_res) != DRIZZLE_RETURN_OK)
+    die("Warning count is %u but didn't get any warnings", count);
+
+  append_result(ds, &warn_res);
+  drizzle_result_free(&warn_res);
 
   return(count);
 }
@@ -4980,46 +5063,46 @@
                              int flags, char *query, int query_len,
                              string *ds, string *ds_warnings)
 {
-  DRIZZLE_RES *res= 0;
-  DRIZZLE *drizzle= &cn->drizzle;
-  int err= 0, counter= 0;
+  drizzle_result_st res;
+  drizzle_return_t ret;
+  drizzle_con_st *con= &cn->con;
+  int err= 0;
 
   if (flags & QUERY_SEND_FLAG)
   {
     /*
      * Send the query
      */
-    if (do_send_query(cn, query, query_len, flags))
+    if (drizzle_query(con, &res, query, query_len, &ret) == NULL ||
+        ret != DRIZZLE_RETURN_OK)
     {
-      handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
-                   drizzleclient_sqlstate(drizzle), ds);
+      if (ret == DRIZZLE_RETURN_ERROR_CODE)
+      {
+        err= drizzle_result_error_code(&res);
+        handle_error(command, err, drizzle_result_error(&res),
+                     drizzle_result_sqlstate(&res), ds);
+        drizzle_result_free(&res);
+      }
+      else
+      {
+        handle_error(command, ret, drizzle_con_error(con), NULL, ds);
+        err= ret;
+      }
       goto end;
     }
   }
   if (!(flags & QUERY_REAP_FLAG))
     return;
 
-  do
   {
     /*
-      When  on first result set, call drizzleclient_read_query_result to retrieve
-      answer to the query sent earlier
-    */
-    if ((counter==0) && drizzleclient_read_query_result(drizzle))
-    {
-      handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
-                   drizzleclient_sqlstate(drizzle), ds);
-      goto end;
-
-    }
-
-    /*
       Store the result of the query if it will return any fields
     */
-    if (drizzleclient_field_count(drizzle) && ((res= drizzleclient_store_result(drizzle)) == 0))
+    if (drizzle_result_column_count(&res) &&
+        (ret= drizzle_result_buffer(&res)) != DRIZZLE_RETURN_OK)
     {
-      handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
-                   drizzleclient_sqlstate(drizzle), ds);
+      handle_error(command, ret, drizzle_con_error(con), NULL, ds);
+      err= ret;
       goto end;
     }
 
@@ -5027,18 +5110,15 @@
     {
       uint64_t affected_rows= 0;    /* Ok to be undef if 'disable_info' is set */
 
-      if (res)
+      if (drizzle_result_column_count(&res))
       {
-        const DRIZZLE_FIELD *fields= drizzleclient_fetch_fields(res);
-        uint32_t num_fields= drizzleclient_num_fields(res);
-
         if (display_metadata)
-          append_metadata(ds, fields, num_fields);
+          append_metadata(ds, &res);
 
         if (!display_result_vertically)
-          append_table_headings(ds, fields, num_fields);
+          append_table_headings(ds, &res);
 
-        append_result(ds, res);
+        append_result(ds, &res);
       }
 
       /*
@@ -5046,16 +5126,16 @@
         query to find the warnings
       */
       if (!disable_info)
-        affected_rows= drizzleclient_affected_rows(drizzle);
+        affected_rows= drizzle_result_affected_rows(&res);
 
       /*
         Add all warnings to the result. We can't do this if we are in
         the middle of processing results from multi-statement, because
         this will break protocol.
       */
-      if (!disable_warnings && !drizzleclient_more_results(drizzle))
+      if (!disable_warnings)
       {
-        if (append_warnings(ds_warnings, drizzle) || ds_warnings->length())
+        if (append_warnings(ds_warnings, con, &res) || ds_warnings->length())
         {
           ds->append("Warnings:\n", 10);
           ds->append(ds_warnings->c_str(), ds_warnings->length());
@@ -5063,24 +5143,11 @@
       }
 
       if (!disable_info)
-        append_info(ds, affected_rows, drizzleclient_info(drizzle));
+        append_info(ds, affected_rows, drizzle_result_info(&res));
     }
 
-    if (res)
-    {
-      drizzleclient_free_result(res);
-      res= 0;
-    }
-    counter++;
-  } while (!(err= drizzleclient_next_result(drizzle)));
-  if (err > 0)
-  {
-    /* We got an error from drizzleclient_next_result, maybe expected */
-    handle_error(command, drizzleclient_errno(drizzle), drizzleclient_error(drizzle),
-                 drizzleclient_sqlstate(drizzle), ds);
-    goto end;
+    drizzle_result_free(&res);
   }
-  assert(err == -1); /* Successful and there are no more results */
 
   /* If we come here the query is both executed and read successfully */
   handle_no_error(command);
@@ -5092,7 +5159,7 @@
     to the server into the drizzletest builtin variable $drizzleclient_errno. This
     variable then can be used from the test case itself.
   */
-  var_set_errno(drizzleclient_errno(drizzle));
+  var_set_errno(err);
   return;
 }
 
@@ -5127,8 +5194,7 @@
       returned a valid reponse. Don't allow 2013 or 2006 to trigger an
       abort_not_supported_test
     */
-    if (err_errno == CR_SERVER_LOST ||
-        err_errno == CR_SERVER_GONE_ERROR)
+    if (err_errno == DRIZZLE_RETURN_SERVER_GONE)
       die("require query '%s' failed: %d: %s", command->query,
           err_errno, err_error);
 
@@ -5146,7 +5212,7 @@
          (command->expected_errors.err[i].code.errnum == err_errno)) ||
         ((command->expected_errors.err[i].type == ERR_SQLSTATE) &&
          (strncmp(command->expected_errors.err[i].code.sqlstate,
-                  err_sqlstate, SQLSTATE_LENGTH) == 0)))
+                  err_sqlstate, DRIZZLE_MAX_SQLSTATE_SIZE) == 0)))
     {
       if (!disable_result_log)
       {
@@ -5495,7 +5561,7 @@
                 1024, 0, 0, get_var_key, var_free, MYF(0)))
     die("Variable hash initialization failed");
 
-  var_set_string("$DRIZZLE_SERVER_VERSION", drizzleclient_get_client_info());
+  var_set_string("$DRIZZLE_SERVER_VERSION", drizzle_version());
 
   memset(&master_pos, 0, sizeof(master_pos));
 
@@ -5520,15 +5586,15 @@
     cur_file->lineno= 1;
   }
   cur_con= connections;
-  if (!( drizzleclient_create(&cur_con->drizzle)))
-    die("Failed in drizzleclient_create()");
-  if (opt_compress)
-    drizzleclient_options(&cur_con->drizzle,DRIZZLE_OPT_COMPRESS,NULL);
+  if (!( drizzle_create(&cur_con->drizzle)))
+    die("Failed in drizzle_create()");
+  if (!( drizzle_con_create(&cur_con->drizzle, &cur_con->con)))
+    die("Failed in drizzle_con_create()");
 
   if (!(cur_con->name = strdup("default")))
     die("Out of memory");
 
-  safe_connect(&cur_con->drizzle, cur_con->name, opt_host, opt_user, opt_pass,
+  safe_connect(&cur_con->con, cur_con->name, opt_host, opt_user, opt_pass,
                opt_db, opt_port);
 
   /* Use all time until exit if no explicit 'start_timer' */
@@ -5542,7 +5608,7 @@
   var_set_errno(-1);
 
   /* Update $drizzleclient_get_server_version to that of current connection */
-  var_set_drizzleclient_get_server_version(&cur_con->drizzle);
+  var_set_drizzleclient_get_server_version(&cur_con->con);
 
   if (opt_include)
   {
@@ -5730,7 +5796,13 @@
         command->last_argument= command->end;
         break;
       case Q_PING:
-        (void) drizzleclient_ping(&cur_con->drizzle);
+        {
+          drizzle_result_st result;
+          drizzle_return_t ret;
+          (void) drizzle_ping(&cur_con->con, &result, &ret);
+          if (ret == DRIZZLE_RETURN_OK || ret == DRIZZLE_RETURN_ERROR_CODE)
+            drizzle_result_free(&result);
+        }
         break;
       case Q_EXEC:
         do_exec(command);
@@ -5748,10 +5820,10 @@
         do_set_charset(command);
         break;
       case Q_DISABLE_RECONNECT:
-        set_reconnect(&cur_con->drizzle, 0);
+        set_reconnect(&cur_con->con, 0);
         break;
       case Q_ENABLE_RECONNECT:
-        set_reconnect(&cur_con->drizzle, 1);
+        set_reconnect(&cur_con->con, 1);
         break;
       case Q_DISABLE_PARSING:
         if (parsing_disabled == 0)

